package com.ynet.life.cache;

import com.ynet.gene.core.Context;
import com.ynet.gene.data.DataElement;
import com.ynet.gene.data.DataField;
import com.ynet.gene.data.DuplicatedDataNameException;
import com.ynet.gene.data.IndexedCollection;
import com.ynet.gene.data.InvalidArgumentException;
import com.ynet.gene.data.ObjectNotFoundException;
import com.ynet.gene.service.GENEService;
import com.ynet.life.base.LifeBeanRefUtil;
import com.ynet.life.cache.coherence.CoherenceCache;
import com.ynet.life.cache.memcached.MemcachedCache;
import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

/* loaded from: com_ynet_life_cache.jar:com/ynet/life/cache/CacheService.class */
public class CacheService extends GENEService {
    private String type = null;
    private String JNDIDataSource = null;
    private Cache cache = null;

    public Cache getCache() {
        this.cache = getCache(null);
        return this.cache;
    }

    public Cache getCache(String name) {
        if (this.cache != null && this.cache.getCacheName().equals(name)) {
            return this.cache;
        }
        if ("memcached".equalsIgnoreCase(this.type)) {
            this.cache = new MemcachedCache(name);
        } else if ("coherence".equalsIgnoreCase(this.type)) {
            this.cache = new CoherenceCache(name);
        }
        return this.cache;
    }

    public void setType(String type) {
        this.type = type;
    }

    public void setJNDIDataSource(String jNDIDataSource) {
        this.JNDIDataSource = jNDIDataSource;
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v18, types: [boolean] */
    /* JADX WARN: Type inference failed for: r0v24, types: [boolean] */
    /* JADX WARN: Type inference failed for: r0v3 */
    /* JADX WARN: Type inference failed for: r0v35, types: [java.lang.Class] */
    public static void synCachedFromContext(Cache cache, Context context, String key, Object obj) {
        InvalidArgumentException containsKey;
        String classpath = obj.getClass().getName();
        ClassNotFoundException classNotFoundException = 0;
        Class cls = null;
        try {
            classNotFoundException = Class.forName(classpath);
            cls = classNotFoundException;
        } catch (ClassNotFoundException e) {
            classNotFoundException.printStackTrace();
        }
        Map<String, Object> valMap = new HashMap<>();
        if (cls != null) {
            Field[] fieldlist = cls.getDeclaredFields();
            for (Field field : fieldlist) {
                String name = field.getName();
                if (context != null && (containsKey = context.containsKey(name)) != 0) {
                    try {
                        Object objTarget = null;
                        Object objs = context.getDataElement(name);
                        containsKey = objs instanceof DataField;
                        if (containsKey != 0) {
                            objTarget = ((DataField) objs).getValue();
                        } else if (objs instanceof IndexedCollection) {
                            objTarget = (IndexedCollection) objs;
                        }
                        valMap.put(name, objTarget);
                    } catch (InvalidArgumentException e2) {
                        containsKey.printStackTrace();
                    } catch (ObjectNotFoundException e3) {
                        containsKey.printStackTrace();
                    }
                }
            }
        }
        LifeBeanRefUtil.setFieldValue(obj, valMap);
        cache.put(key, obj);
    }

    public static Map<String, Object> synCachedFromContext(Context context, Map<String, Object> map, ArrayList<String> list) {
        for (int i = 0; i < list.size(); i++) {
            String key = list.get(i);
            if (context.containsKey(key)) {
                map.put(key, context.get(key));
            }
        }
        return map;
    }

    public void setCachedValue(Context context, String dataField, Object obj) throws ObjectNotFoundException, InvalidArgumentException {
        Map<String, Object> valMap = new HashMap<>();
        if (dataField.contains("|")) {
            String[] arr = dataField.split("|");
            for (String key : arr) {
                Object value = context.getDataValue(key);
                valMap.put(key, value);
            }
        } else {
            Object value2 = (String) context.getDataValue("");
            valMap.put("", value2);
        }
        LifeBeanRefUtil.setFieldValue(obj, valMap);
    }

    public void setCachedValue(Context context, String dataField, Map<String, Object> map) throws ObjectNotFoundException, InvalidArgumentException {
        if (dataField.contains("|")) {
            String[] arr = dataField.split("|");
            for (String key : arr) {
                Object value = context.get(key);
                map.put(key, value);
            }
            return;
        }
        Object value2 = (String) context.get(dataField);
        map.put(null, value2);
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v18, types: [java.lang.String] */
    /* JADX WARN: Type inference failed for: r0v19, types: [java.lang.Exception] */
    /* JADX WARN: Type inference failed for: r0v20, types: [java.lang.Class] */
    /* JADX WARN: Type inference failed for: r0v24, types: [java.lang.Object] */
    /* JADX WARN: Type inference failed for: r0v26, types: [java.lang.Class] */
    /* JADX WARN: Type inference failed for: r0v3 */
    /* JADX WARN: Type inference failed for: r0v4, types: [java.lang.ClassNotFoundException] */
    public void synCached2Context(Context context, Object obj) {
        String classpath = obj.getClass().getName();
        ?? r0 = 0;
        Class cls = null;
        try {
            r0 = Class.forName(classpath);
            cls = r0;
        } catch (ClassNotFoundException e) {
            r0.printStackTrace();
        }
        if (cls != null) {
            Field[] fieldlist = cls.getDeclaredFields();
            for (Field field : fieldlist) {
                String name = field.getName();
                if (context != null && !name.equals("serialVersionUID")) {
                    ?? r02 = "get" + toFirstLetterUpperCase(name);
                    try {
                        Object value = cls.getMethod(r02, new Class[0]).invoke(obj, new Object[0]);
                        r02 = context.put(name, value);
                    } catch (Exception e2) {
                        r02.printStackTrace();
                    }
                }
            }
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v13, types: [boolean] */
    /* JADX WARN: Type inference failed for: r0v19, types: [boolean] */
    public void synCachedParas2Context(Context context, Map<String, Object> map) {
        ObjectNotFoundException containsKey;
        for (Map.Entry<String, Object> entry : map.entrySet()) {
            Object keys = entry.getKey();
            Object value = entry.getValue();
            if (context != null && (containsKey = context.containsKey(keys)) == 0) {
                try {
                    containsKey = context.getDataElement((String) keys) instanceof DataField;
                    if (containsKey != 0) {
                        context.put(keys.toString(), value);
                    } else {
                        context.removeDataElement((String) keys);
                        context.addDataElement((DataElement) value);
                    }
                } catch (ObjectNotFoundException e) {
                    containsKey.printStackTrace();
                } catch (InvalidArgumentException e2) {
                    containsKey.printStackTrace();
                } catch (DuplicatedDataNameException e3) {
                    containsKey.printStackTrace();
                }
            }
        }
    }

    private String toFirstLetterUpperCase(String str) {
        if (str == null || str.length() < 2) {
            return str;
        }
        String firstLetter = str.substring(0, 1).toUpperCase();
        return String.valueOf(firstLetter) + str.substring(1, str.length());
    }
}
